#!/bin/ksh
##  Usage: XXXX - DB_UNIQUE_NAME

EXIT_CODE=0

cleanup () {
find $1 -name '*' -mtime +$2 -exec rm -f {} \; -print
}

if [ "$1" = "" ]
then
   echo "Usage: $0 <DB_UNIQUE_NAME> "
   EXIT_CODE=100
   exit ${EXIT_CODE}
fi

ARG1=`echo $1 | tr "[a-z]" "[A-Z]"`   ## Convert to uppercase ##
####HOME=/oracle; export HOME
HOME=/home/oracle; export HOME
####. $HOME/DBA_MISC/bin/.${ARG1}_profile 
. $HOME/.bash_profile 

## Set RMAN Script Location -- this could be in the profile
SCRIPT_BASE=/home/oracle/DBA
SCRIPT_BIN=$SCRIPT_BASE/bin
SCRIPT_LOG=$SCRIPT_BASE/log
SCRIPT_TMP=$SCRIPT_BASE/TMP
SCRIPT_SQL=$SCRIPT_BASE/SQL
## this is the mapped expdp location
DATAPUMP_LOC=/home/oracle/DBA/datapump
## export location
EXPORT_LOC=/home/oracle/DBA
export SCRIPT_BASE SCRIPT_BIN SCRIPT_LOG SCRIPT_TMP SCRIPT_SQL DATAPUMP_LOC EXPORT_LOC

###########################################################################################################################
#  Prepare envs and alias

DAY_PREFIX=`date | cut -c1-3`

STARTTIME=`date +"%s"`
TIMESTAMP=`date +"%Y%m%d%H%M%S"`
#### define variables: see .SID_profile
BACKUP_TYPE=expdp
BACKUP_DIR=DATAPUMP
LOG=${SCRIPT_LOG}/${BACKUP_TYPE}_${ORACLE_SID}_${TIMESTAMP}.log
LOCAL_SQL=${SCRIPT_SQL}/${ORACLE_SID}_${BACKUP_TYPE}.par
EMAIL=jason.wong@somecompany.com
TEXT=jason.wong@somecompany.com
EXPDATE=`date +"%m-%d-%y %T"`

if [ "${DATAPUMP_LOC}" = "" ]
then
EXPORT_FORMAT=" "
else
EXPORT_FORMAT=${ORACLE_SID}_${BACKUP_TYPE}_${TIMESTAMP}_%u.dmp
####EXPORT_FORMAT=${ORACLE_SID}_${BACKUP_TYPE}_${TIMESTAMP}.dmp
EXPORTLOG_FORMAT=${ORACLE_SID}_${BACKUP_TYPE}_${TIMESTAMP}.log
fi


RANDOM=$$
RD=$RANDOM

#  TEST IF REALLY EXPORT ALREADY RUNNING
FFL=` ps -ef | grep EXP | grep "$ORACLE_SID" | grep full | grep log `


#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
## start if-fi loop 
###########################################################################################################################

if [ -n "$FFL" ]; then

TEMPLOG=${SCRIPT_TMP}/tmplog_${ORACLE_SID}.txt
echo "EXPORT quitted as another EXPORT session has already been RUNNING for" > $TEMPLOG
echo $(($LAG*24)) "HOURS" >> $TEMPLOG
echo "Please check backup log to see if EXPORT hangs there" >> $TEMPLOG
mail -s "EXPORT of DATABASE <$ORACLE_SID> type <$BACKUP_TYPE> starting at <$EXPDATE> has EXITED as EXPORT is already running" $EMAIL < $TEMPLOG
rm -f $TEMPLOG 
EXIT_CODE=1
exit ${EXIT_CODE}

#$ start else

else


###########################################################################################################################
#
#datapump begins; 
#
###########################################################################################################################
echo " " >>${LOG}
echo "Directory Name: ${BACKUP_TYPE}" >>${LOG}
echo "Export File Format: ${EXPORT_FORMAT}" >>${LOG}
echo "Backup Location: ${DATAPUMP_LOC}" >>${LOG}
echo " "

${ORACLE_HOME}/bin/expdp PARFILE=${LOCAL_SQL} DUMPFILE=${EXPORT_FORMAT} LOGFILE=${EXPORTLOG_FORMAT} >> $LOG 2>&1


# use gzip if oracle version is not 12
ORACLE_VERSION=`echo $ORACLE_HOME | grep '\/12.' | wc -l | awk '{print $1}'`
if [ $ORACLE_VERSION -ne "1" ]; then
#echo "datapump loc: ${DATAPUMP_LOC}"
gzip ${DATAPUMP_LOC}/*.*
fi
###########################################################################################################################

END_TIME=`date +"%m-%d-%y %T"`
ENDTIME=`date +"%s"`

echo " " >>${LOG}
echo "EXPORT backup job for ${ORACLE_SID} start time: ${EXPDATE}; End Time: ${END_TIME}. " >>${LOG}

RC=`/bin/grep -e "EXP-" -e "ORA-" -e "LRM-" -e "SP2-" -e "error:" ${LOG} | wc -l | awk '{print $1}'`


if [ $RC -ne "0" ]; then
EXIT_CODE=1
echo " " >>${LOG}
echo "Job Failed. See Log File at ${LOG}" >>${LOG}
mail -s "<${BACKUP_TYPE}> BACKUP of DATABASE <${ORACLE_SID}> type <${BACKUP_TYPE}> starting at <${RMANDATE}> has FAILED" ${EMAIL} < ${LOG}


else
EXIT_CODE=0


echo " " >>${LOG}
echo "Cleanup Export Files - " >>${LOG}
echo "Files deleted from export location: ${DATAPUMP_LOC}" >>${LOG}
echo " " >>${LOG}
cleanup ${DATAPUMP_LOC} 1 >>${LOG}

fi

cleanup ${SCRIPT_LOG} 30
cleanup ${SCRIPT_TMP} 30
#$   end if
#$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
fi

exit ${EXIT_CODE}
